% driver.m
%
% This is the driver for Minimum Relative Entropy method.  The user sets up
% the necessary parameters here, and then calls the MRE routine, mre.m

% This file contains the parameters for all MRE runs used to create the
% figures in Neupauer, R.M., B. Borchers, and J.L. Wilson, Comparison
% of Inverse Methods for Reconstructing the Release History of a
% Groundwater Contamination Source, submitted to Water Resources Research.

clear all

% set up input for domre.m
params=[1.0, 1.0];   % [v,D]
xsample=[0.01,25.05,50:10:250,275,300];
tsample=300;
nt=100;
tmax=250.;
tmin=0.01;
tollam=.01;
kernfn='kernel';
tol=0.0001;
maxiter=30;
lamiter=30;
expvalue=0.8*ones(nt,1);
lower=zeros(nt,1);

randomdev=[   -1.2276;   -0.2751;   -0.1604;   -1.0836;   -1.9542;...
	   -0.9095;   -0.0056;   -1.7235;    1.2631;   -0.6004;...
	   -2.0639;    0.1109;    1.4876;    0.0530;    0.1620;...
	   -0.0269;    0.1736;    0.8822;    0.1823;    0.7553;...
	    0.5080;    0.1319;    0.2801;   -0.9828;   -0.9441];

%  Figure No.      	runid
% 	2b		ideal
%	2d		errorske
%	3b		nons
%	3d		brsqer
%	4b		skerrskmod
%	4c		skerrwumod
%	5b		wuerrskmod
%	5c		wuerrwumod
%	6a		errorske
%	6b		errorsku
%	6c		errorsko
%	8a		ub1l
%	8b		ub1m
%	8c		ub1h

runid=input('Enter the run identifier >   ','s');

switch runid
	case 'ideal',
		truefn='cintrue';
		noise=0.0000001;
		upper=1.1*ones(nt,1);
	case 'nons',
		truefn='square';
		noise=0.0000001;
		upper=1.1*ones(nt,1);
	case 'ub1l',
		truefn='square';
		noise=0.0000001;
		upper=1.02*ones(nt,1);
	case 'ub1m',
		truefn='square';
		noise=0.0000001;
		upper=1.5*ones(nt,1);
	case 'ub1h',
		truefn='square';
		noise=0.0000001;
		upper=2.0*ones(nt,1);
	case 'brsqer',
		truefn='square';
		noise=-0.05;
		upper=1.1*ones(nt,1);
	case {'errorske','skerrskmod','wuerrskmod'},
		truefn='cintrue';
		noise=-0.05;
		upper=1.1*ones(nt,1);
	case {'skerrwumod','wuerrwumod'},
		truefn='cintrue';
		noise=0.009;
		upper=1.1*ones(nt,1);
	case 'errorsku'
		truefn='cintrue';
		noise=-0.05/5;
		upper=1.1*ones(nt,1);
	case 'errorsko'
		truefn='cintrue';
		noise=-0.05*5;
		upper=1.1*ones(nt,1);
end

% calculate time array
if (tmax == tsample)
	t=linspace(tmin,tsample,nt+1);
	t=t(1:nt);
else
	t=linspace(tmin,tmax,nt);
end
dt=t(2)-t(1);

% get true source concentration as a function of t
	cin=feval(truefn,t);
	disp('Generated true solution')

% generate sampled data
	[csample,cexact]=...
		getdata(truefn,kernfn,xsample,tsample,...
		params,299,0.);
	disp('Generated sampled data')

if (noise < 0)
	if strcmp(runid,'wuerrskmod')
		csample=cexact+0.009*randomdev;
	elseif strcmp(runid,'errorsku')
		csample=cexact.*(1+0.05*randomdev);
	elseif strcmp(runid,'errorsko')
		csample=cexact.*(1+0.05*randomdev);
	else
		csample=cexact.*(1+abs(noise)*randomdev);
	end
	noise=[0.0 -noise];
else
	if strcmp(runid,'skerrwumod')
		csample=cexact.*(1+0.05*randomdev);
	else	
		csample=cexact+noise*randomdev;
	end
	noise=[noise 0.0];
end

g=getrep(kernfn,t,xsample,tsample,params);

[x,lambda,beta,a,p5,p95]=mre(g,csample,upper,lower,expvalue,noise);

subplot(211)
plot(t,x,t,cin,'--',t,expvalue,':')
h=legend('Fitted','True','Exp. Value')
xlabel('time'),ylabel('Source Concentration');
xlim=250.;
axis([0,xlim,0,1.5])

subplot(212)
plot(xsample,cexact,'-',xsample,csample,'o')
xlabel('Distance')
ylabel('C(x,t)')
legend('True','Sampled')

